@@ -4,17 +4,17 @@
 # extract messages from *.py
 
 # currently, the .pot lives at
-# http://websvn.kde.org/trunk/l10n-kde4/templates/messages/playground-games/kajongg.pot
+# http://websvn.kde.org/trunk/l10n-kf5/templates/messages/kdegames/kajongg.pot
 
 ${EXTRACTRC:-extractrc} src/*.ui src/*.rc >> rc.cpp
 
 ${XGETTEXT:-xgettext} \
 		-ci18n --from-code=UTF-8 --language=Python -k \
-		-kki18n:1 -ki18n:1 -ki18nc:1c,2 -ki18np:1,2 \
+		-ki18n:1 -ki18nc:1c,2 -ki18np:1,2 \
+                -ki18nE:1 -ki18ncE:1c,2 \
 		-ki18ncp:1c,2,3 -ktr2i18n:1 \
 		-kI18N_NOOP:1 -kI18N_NOOP2:1c,2 \
-		-kaliasLocale -kki18n:1 -kki18nc:1c,2 -kki18np:1,2 -kki18ncp:1c,2,3 \
-		-km18n:1 -km18nE:1 -km18nc:1c,2 -km18ncE:1c,2 -km18np:1,2 \
+		-kaliasLocale \
 		-kcreateRule:1 \
 		--no-wrap --msgid-bugs-address=wolfgang@rohdewald.de -o${podir:-.}/kajongg.pot \
 		rc.cpp `find . -name \*.py`
