@@ -1,5 +1,5 @@
 """
-    Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+    Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
     partially based on C++ code from:
     Copyright (C) 2006 Mauricio Piacentini <mauricio@tabuleiro.com>
@@ -19,19 +19,20 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
-from qt import QWidget
-from kde import KLineEdit, KConfig
+from qt import QWidget, QLineEdit
 from background import Background
 from common import Internal
 from guiutil import loadUi
-from log import m18n
+
 
 class BackgroundSelector(QWidget):
+
     """presents all available backgrounds with previews"""
+
     def __init__(self, parent):
         super(BackgroundSelector, self).__init__(parent)
         loadUi(self)
-        self.kcfg_backgroundName = KLineEdit(self)
+        self.kcfg_backgroundName = QLineEdit(self)
         self.kcfg_backgroundName.setVisible(False)
         self.kcfg_backgroundName.setObjectName('kcfg_backgroundName')
         self.setUp()
@@ -39,13 +40,15 @@ class BackgroundSelector(QWidget):
     def setUp(self):
         """fill the selector"""
 
-        #The lineEdit widget holds our background path, but the user does
+        # The lineEdit widget holds our background path, but the user does
         # not manipulate it directly
         self.kcfg_backgroundName.hide()
 
-        self.backgroundNameList.currentRowChanged.connect(self.backgroundRowChanged)
-        self.kcfg_backgroundName.textChanged.connect(self.backgroundNameChanged)
-        self.backgroundList = Background.backgroundsAvailable()
+        self.backgroundNameList.currentRowChanged.connect(
+            self.backgroundRowChanged)
+        self.kcfg_backgroundName.textChanged.connect(
+            self.backgroundNameChanged)
+        self.backgroundList = Background.available()
         for aset in self.backgroundList:
             self.backgroundNameList.addItem(aset.name)
         self.kcfg_backgroundName.setText(Internal.Preferences.backgroundName)
@@ -56,22 +59,16 @@ class BackgroundSelector(QWidget):
         for idx, aset in enumerate(self.backgroundList):
             if aset.desktopFileName == name:
                 igrindex = idx
+                break
         self.backgroundNameList.setCurrentRow(igrindex)
 
     def backgroundRowChanged(self):
         """user selected a new background, update our information about it and paint preview"""
-        selBackground = self.backgroundList[self.backgroundNameList.currentRow()]
+        selBackground = self.backgroundList[
+            self.backgroundNameList.currentRow()]
         self.kcfg_backgroundName.setText(selBackground.desktopFileName)
-
-        config = KConfig(selBackground.path)
-        group = config.group("KMahjonggBackground")
-
-        author = group.readEntry("Author") or m18n("unknown author")
-        description = group.readEntry("Description") or ""
-        authorEmail = group.readEntry("AuthorEmail") or m18n("no E-Mail address available")
-
-        self.backgroundAuthor.setText(author)
-        self.backgroundContact.setText(authorEmail)
-        self.backgroundDescription.setText(description)
+        self.backgroundAuthor.setText(selBackground.author)
+        self.backgroundContact.setText(selBackground.authorEmail)
+        self.backgroundDescription.setText(selBackground.description)
         selBackground.setPalette(self.backgroundPreview)
         self.backgroundPreview.setAutoFillBackground(True)
