@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,16 +23,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 import inspect
 
-from qt import Qt, QDialog, QMessageBox, QWidget
+from twisted.internet.defer import Deferred, succeed
 
 from kde import KMessageBox, KDialog
 
-from twisted.internet.defer import Deferred, succeed
+from qt import Qt, QDialog, QMessageBox, QWidget
 
-from common import Options, Internal, isAlive
+from common import Options, Internal, isAlive, StrMixin
 
 
-class IgnoreEscape(object):
+class IgnoreEscape:
 
     """as the name says. Use as a mixin for dialogs"""
 
@@ -53,7 +53,9 @@ class KDialogIgnoringEscape(KDialog, IgnoreEscape):
 
 class MustChooseKDialog(KDialogIgnoringEscape):
 
-    """this dialog can only be closed if a choice has been done"""
+    """this dialog can only be closed if a choice has been done. Currently,
+    the self.chosen thing is not used, code removed.
+    So this dialog can only be closed by calling accept() or reject()"""
 
     def __init__(self):
         parent = Internal.mainWindow  # default
@@ -69,23 +71,20 @@ class MustChooseKDialog(KDialogIgnoringEscape):
         if not isAlive(parent):
             parent = None
         KDialogIgnoringEscape.__init__(self, parent)
-        self.chosen = None
 
-    def closeEvent(self, event):
-        """allow close only if a choice has been done"""
-        if self.chosen is not None:
-            event.accept()
-        else:
-            event.ignore()
+    def closeEvent(self, event): # pylint: disable=no-self-use
+        """self.chosen is currently not used, never allow this"""
+        event.ignore()
 
 
-class Prompt(MustChooseKDialog):
+class Prompt(MustChooseKDialog, StrMixin):
 
     """common code for things like QuestionYesNo, Information"""
 
     def __init__(self, msg, icon=QMessageBox.Information,
                  buttons=KDialog.Ok, caption=None, default=None):
         """buttons is button codes or-ed like KDialog.Ok | KDialog.Cancel. First one is default."""
+        MustChooseKDialog.__init__(self)
         if r'\n' in msg:
             print(r'*********************** Fix this! Prompt gets \n in', msg)
             msg = msg.replace(r'\n', '\n')
@@ -111,11 +110,8 @@ class Prompt(MustChooseKDialog):
             button = self.default
         return button in (KDialog.Yes, KDialog.Ok)
 
-    def __unicode__(self):
-        return u'Prompt({})'.format(self.msg)
-
     def __str__(self):
-        return 'Prompt({})'.format(self.msg.encode('utf-8'))
+        return self.msg
 
 
 class DeferredDialog(Deferred):
@@ -125,6 +121,7 @@ class DeferredDialog(Deferred):
     def __init__(self, dlg, modal=True, always=False):
         Deferred.__init__(self)
         self.dlg = dlg
+        self.defaultResult = dlg.returns()
         self.modal = modal
         self.always = always
         if Options.gui:
@@ -145,7 +142,7 @@ class DeferredDialog(Deferred):
             return
         scene = Internal.scene
         if not Options.gui or not isAlive(self.dlg):
-            return self.autoAnswer()
+            return self.clicked()
         autoPlay = scene and scene.game and scene.game.autoPlay
         autoAnswerDelayed = autoPlay and not self.always
         if self.modal and not autoAnswerDelayed:
@@ -155,31 +152,27 @@ class DeferredDialog(Deferred):
         if autoAnswerDelayed:
             Internal.reactor.callLater(
                 Internal.Preferences.animationDuration() / 500.0,
-                self.autoAnswer)
-
-    def autoAnswer(self):
-        """autoPlay gets autoAnswer"""
-        result = self.dlg.returns()
-        if Internal.scene and isAlive(self.dlg):
-            self.dlg.hide()
-        self.dlg = None
-        self.callback(result)
+                self.clicked)
 
     def clicked(self, button=None):
         """we got a reaction"""
-        assert self.dlg
         if self.dlg:
             result = self.dlg.returns(button)
-            self.dlg.hide()
-            self.dlg = None
-            self.callback(result)
+        else:
+            result = None
+        self.__removeFromScene()
+        self.callback(result)
 
     def cancel(self):
         """we want no answer, just let the dialog disappear"""
-        if self.dlg:
+        self.__removeFromScene()
+        Deferred.cancel(self)
+
+    def __removeFromScene(self):
+        """remove ourself"""
+        if self.dlg and Internal.scene and isAlive(self.dlg):
             self.dlg.hide()
         self.dlg = None
-        Deferred.cancel(self)
 
 
 class QuestionYesNo(DeferredDialog):
@@ -216,10 +209,10 @@ class Sorry(DeferredDialog):
 
     """wrapper, see class Prompt"""
 
-    def __init__(self, msg, modal=True, caption=None):
+    def __init__(self, msg, modal=True, caption=None, always=False):
         dialog = Prompt(msg, icon=QMessageBox.Information,
                         buttons=KDialog.Ok, caption=caption or 'Sorry')
-        DeferredDialog.__init__(self, dialog, modal=modal)
+        DeferredDialog.__init__(self, dialog, modal=modal, always=always)
 
 
 def NoPrompt(dummyMsg):
