@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,19 +20,19 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 import datetime
 
-from kde import KIcon
-from dialogs import WarningYesNo
-
-from qt import Qt, toQVariant, RealQVariant, variantValue
+from qt import Qt, QModelIndex
 from qt import QAbstractTableModel, QDialogButtonBox, QDialog
 from qt import QHBoxLayout, QVBoxLayout, QCheckBox
 from qt import QItemSelectionModel, QAbstractItemView
 
-from log import logException, m18n, m18nc
+from dialogs import WarningYesNo
+from kde import KIcon
+from mi18n import i18n, i18nc
+from log import logException
 from query import Query
 from guiutil import MJTableView, decorateWindow
 from statesaver import StateSaver
-from common import Debug, nativeString, unicode
+from common import Debug
 from modeltest import ModelTest
 
 
@@ -48,8 +48,11 @@ class GamesModel(QAbstractTableModel):
         """including the hidden col 0"""
         return 3
 
-    def rowCount(self, dummyParent=None):
+    def rowCount(self, parent=None):
         """how many games"""
+        if parent and parent.isValid():
+            # we have only top level items
+            return 0
         return len(self._resultRows)
 
     def setResultset(self, rows):
@@ -60,8 +63,13 @@ class GamesModel(QAbstractTableModel):
         finally:
             self.endResetModel()
 
-    def index(self, row, column, dummyParent=None):
+    def index(self, row, column, parent=None):
         """helper"""
+        if (row < 0
+                or column < 0
+                or row >= self.rowCount(parent)
+                or column >= self.columnCount(parent)):
+            return QModelIndex()
         return self.createIndex(row, column, 0)
 
     def data(self, index, role=None):
@@ -69,30 +77,28 @@ class GamesModel(QAbstractTableModel):
         if role is None:
             role = Qt.DisplayRole
         if not (index.isValid() and role == Qt.DisplayRole):
-            return toQVariant()
+            return
         if role == Qt.DisplayRole:
-            unformatted = unicode(
-                self._resultRows[index.row()][index.column()])
+            unformatted = str(
+                self._resultRows[index.row()][index.column()]) # TODO: brauche ich str?
             if index.column() == 2:
                 # we do not yet use this for listing remote games but if we do
                 # this translation is needed for robot players
-                names = [m18n(name) for name in unformatted.split('///')]
-                return toQVariant(', '.join(names))
+                names = [i18n(name) for name in unformatted.split('///')]
+                return ', '.join(names)
             elif index.column() == 1:
                 dateVal = datetime.datetime.strptime(
                     unformatted, '%Y-%m-%dT%H:%M:%S')
-                return toQVariant(nativeString(dateVal.strftime('%c')))
+                return dateVal.strftime('%c')
             elif index.column() == 0:
-                return toQVariant(int(unformatted))
-        with RealQVariant():
-            return QAbstractTableModel.data(self, index, role)
+                return int(unformatted)
+        return QAbstractTableModel.data(self, index, role)
 
     def headerData(self, section, orientation, role):
         """for the two visible columns"""
         # pylint: disable=no-self-use
         if orientation == Qt.Horizontal and role == Qt.DisplayRole:
-            return toQVariant((m18n("Started"), m18n("Players"))[section - 1])
-        return toQVariant()
+            return (i18n("Started"), i18n("Players"))[section - 1]
 
 
 class Games(QDialog):
@@ -103,7 +109,7 @@ class Games(QDialog):
         super(Games, self).__init__(parent)
         self.selectedGame = None
         self.onlyPending = True
-        decorateWindow(self, m18nc('kajongg', 'Games'))
+        decorateWindow(self, i18nc('kajongg', 'Games'))
         self.setObjectName('Games')
         self.resize(700, 400)
         self.model = GamesModel()
@@ -120,19 +126,19 @@ class Games(QDialog):
         self.buttonBox = QDialogButtonBox(self)
         self.buttonBox.setStandardButtons(QDialogButtonBox.Cancel)
         self.newButton = self.buttonBox.addButton(
-            m18nc('start a new game', "&New"), QDialogButtonBox.ActionRole)
+            i18nc('start a new game', "&New"), QDialogButtonBox.ActionRole)
         self.newButton.setIcon(KIcon("document-new"))
         self.newButton.clicked.connect(self.accept)
         self.loadButton = self.buttonBox.addButton(
-            m18n("&Load"), QDialogButtonBox.AcceptRole)
+            i18n("&Load"), QDialogButtonBox.AcceptRole)
         self.loadButton.clicked.connect(self.loadGame)
         self.loadButton.setIcon(KIcon("document-open"))
         self.deleteButton = self.buttonBox.addButton(
-            m18n("&Delete"), QDialogButtonBox.ActionRole)
+            i18n("&Delete"), QDialogButtonBox.ActionRole)
         self.deleteButton.setIcon(KIcon("edit-delete"))
         self.deleteButton.clicked.connect(self.delete)
 
-        chkPending = QCheckBox(m18n("Show only pending games"), self)
+        chkPending = QCheckBox(i18n("Show only pending games"), self)
         chkPending.setChecked(True)
         cmdLayout = QHBoxLayout()
         cmdLayout.addWidget(chkPending)
@@ -195,7 +201,7 @@ class Games(QDialog):
         """returns the model index for game"""
         for row in range(self.model.rowCount()):
             idx = self.model.index(row, 0)
-            if variantValue(self.model.data(idx, 0)) == game:
+            if self.model.data(idx, 0) == game:
                 return idx
         return self.model.index(0, 0)
 
@@ -203,7 +209,7 @@ class Games(QDialog):
         """returns the game id of the selected game"""
         rows = self.selection.selectedRows()
         if rows:
-            return variantValue(self.model.data(rows[0], 0))
+            return self.model.data(rows[0], 0)
         else:
             return 0
 
@@ -232,12 +238,12 @@ class Games(QDialog):
                     Query("DELETE FROM game WHERE id = ?", (game, ))
                 self.setQuery()  # just reload entire table
         allGames = self.view.selectionModel().selectedRows(0)
-        deleteGames = list(variantValue(x.data()) for x in allGames)
+        deleteGames = list(x.data() for x in allGames)
         if len(deleteGames) == 0:
             # should never happen
             logException('delete: 0 rows selected')
         WarningYesNo(
-            m18n(
+            i18n(
                 "Do you really want to delete <numid>%1</numid> games?<br>"
                 "This will be final, you cannot cancel it with "
                 "the cancel button",
