@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-Copyright (C) 2010-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2010-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 partially based on C++ code from:
 Copyright (C) 2006 Mauricio Piacentini <mauricio@tabuleiro.com>
@@ -22,12 +22,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 import os
 
-from qt import uic, toQVariant, variantValue
+from qt import uic, QStandardPaths
 from qt import QComboBox, QTableView, QSizePolicy, QAbstractItemView
+from qt import QTransform
 
-from kde import KStandardDirs, KIcon
+from kde import KIcon
 
-from log import m18n
+from log import i18n
 
 
 def loadUi(base):
@@ -36,8 +37,10 @@ def loadUi(base):
     name = base.__class__.__name__.lower() + '.ui'
     if os.path.exists(name):
         directory = os.getcwd()
+    elif os.path.exists('share/kajongg/{}'.format(name)):
+        directory = 'share/kajongg'
     else:
-        directory = os.path.dirname(str(KStandardDirs.locate("appdata", name)))
+        directory = os.path.dirname(QStandardPaths.locate(QStandardPaths.AppDataLocation, name))
     uic.loadUi(os.path.join(directory, name), base)
 
 
@@ -74,8 +77,7 @@ class ListComboBox(QComboBox):
     @property
     def items(self):
         """combo box items"""
-        return [variantValue(self.itemData(idx))
-                for idx in range(self.count())]
+        return [self.itemData(idx) for idx in range(self.count())]
 
     @items.setter
     def items(self, items):
@@ -83,7 +85,7 @@ class ListComboBox(QComboBox):
         self.clear()
         if items:
             for item in items:
-                self.addItem(m18n(item.name), toQVariant(item))
+                self.addItem(i18n(item.name), item)
 
     def findItem(self, search):
         """returns the index or -1 of not found """
@@ -99,7 +101,7 @@ class ListComboBox(QComboBox):
     @property
     def current(self):
         """current item"""
-        return variantValue(self.itemData(self.currentIndex()))
+        return self.itemData(self.currentIndex())
 
     @current.setter
     def current(self, item):
@@ -110,7 +112,7 @@ class ListComboBox(QComboBox):
         self.setCurrentIndex(newIdx)
 
 
-class Painter(object):
+class Painter:
 
     """a helper class for painting: saves/restores painter"""
 
@@ -127,7 +129,7 @@ class Painter(object):
         self.painter.restore()
 
 
-class BlockSignals(object):
+class BlockSignals:
 
     """a helper class for temporary blocking of Qt signals"""
 
@@ -152,7 +154,33 @@ class BlockSignals(object):
 def decorateWindow(window, name=None):
     """standard Kajongg window title and icon"""
     if name:
-        window.setWindowTitle(u'{} – {}'.format(name, m18n('Kajongg')))
+        window.setWindowTitle('{} – {}'.format(name, i18n('Kajongg')))
     else:
-        window.setWindowTitle(m18n('Kajongg'))
+        window.setWindowTitle(i18n('Kajongg'))
     window.setWindowIcon(KIcon('kajongg'))
+
+
+def rotateCenter(item, angle):
+    """rotates a QGraphicsItem around its center
+    rotateCenter and sceneRotation could be a mixin class but there are so many
+    classes needing this. If and when more QGraphicsItem* classes are changed
+    to QGraphicsObject, those could be moved to GraphicsObject(QGraphicsObject)"""
+    center = item.boundingRect().center()
+    centerX, centerY = center.x() * item.scale(), center.y() * item.scale()
+    item.setTransform(QTransform().translate(
+        centerX, centerY).rotate(angle).translate(-centerX, -centerY))
+
+def sceneRotation(item):
+    """the combined rotation of item and all parents in degrees: 0,90,180 or 270"""
+    transform = item.sceneTransform()
+    matrix = (
+        round(transform.m11()),
+        round(transform.m12()),
+        round(transform.m21()),
+        round(transform.m22()))
+    matrix = tuple(1 if x > 0 else -1 if x < 0 else 0 for x in matrix)
+    rotations = {(0, 0, 0, 0): 0, (1, 0, 0, 1): 0, (
+        0, 1, -1, 0): 90, (-1, 0, 0, -1): 180, (0, -1, 1, 0): 270}
+    if matrix not in rotations:
+        raise Exception('matrix unknown:%s' % str(matrix))
+    return rotations[matrix]
