@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2009-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -28,14 +28,13 @@ from qt import QDialog, QVBoxLayout, QGridLayout, \
     QLabel, QPushButton, QWidget, \
     QProgressBar, QRadioButton, QSpacerItem, QSizePolicy
 
-from kde import usingKDE, KIcon, KDialog
+from kde import KIcon, KDialog
 from dialogs import Sorry, Information, QuestionYesNo, KDialogIgnoringEscape
 from guiutil import decorateWindow
-from log import m18n, logWarning, logException, logDebug
+from log import i18n, logWarning, logException, logDebug
 from message import Message, ChatMessage
 from chat import ChatWindow
 from common import Options, SingleshotOptions, Internal, Debug, isAlive
-from common import nativeString, nativeStringArgs
 from query import Query
 from board import Board
 from client import Client, ClientTable
@@ -59,7 +58,7 @@ class SelectChow(KDialogIgnoringEscape):
         self.selectedChow = None
         self.deferred = deferred
         layout = QVBoxLayout()
-        label = QLabel(m18n('Which chow do you want to expose?'))
+        label = QLabel(i18n('Which chow do you want to expose?'))
         layout.addWidget(label)
         layout.setAlignment(label, Qt.AlignHCenter)
         self.buttons = []
@@ -97,7 +96,7 @@ class SelectKong(KDialogIgnoringEscape):
         self.selectedKong = None
         self.deferred = deferred
         layout = QVBoxLayout()
-        label = QLabel(m18n('Which kong do you want to declare?'))
+        label = QLabel(i18n('Which kong do you want to declare?'))
         layout.addWidget(label)
         layout.setAlignment(label, Qt.AlignHCenter)
         self.buttons = []
@@ -127,9 +126,10 @@ class DlgButton(QPushButton):
         QPushButton.__init__(self, parent)
         self.message = message
         self.client = parent.client
+        self.setMinimumHeight(25)
         self.setText(message.buttonCaption())
 
-    def decorate(self, uiTile):
+    def setMeaning(self, uiTile):
         """give me caption, shortcut, tooltip, icon"""
         txt, warn, _ = self.message.toolTip(
             self, uiTile.tile if uiTile else None)
@@ -163,11 +163,12 @@ class ClientDialog(QDialog):
 
     def __init__(self, client, parent=None):
         QDialog.__init__(self, parent)
-        decorateWindow(self, m18n('Choose'))
+        decorateWindow(self, i18n('Choose'))
         self.setObjectName('ClientDialog')
         self.client = client
         self.layout = QGridLayout(self)
         self.progressBar = QProgressBar()
+        self.progressBar.setMinimumHeight(25)
         self.timer = QTimer()
         if not client.game.autoPlay:
             self.timer.timeout.connect(self.timeout)
@@ -210,7 +211,7 @@ class ClientDialog(QDialog):
         if not self.client.game:
             return
         for button in self.buttons:
-            button.decorate(self.client.game.myself.handBoard.focusTile)
+            button.setMeaning(self.client.game.myself.handBoard.focusTile)
         for uiTile in self.client.game.myself.handBoard.lowerHalfTiles():
             txt = []
             for button in self.buttons:
@@ -354,7 +355,7 @@ class ClientDialog(QDialog):
             answer = button.message
         if not self.client.game.myself.sayable[answer]:
             self.proposeAction().setFocus() # go back to default action
-            self.sorry = Sorry(m18n('You cannot say %1', answer.i18nName))
+            self.sorry = Sorry(i18n('You cannot say %1', answer.i18nName))
             return
         self.timer.stop()
         self.answered = True
@@ -432,7 +433,7 @@ class HumanClient(Client):
                 voiceId = voice.md5sum
             if Debug.sound and voiceId:
                 logDebug(
-                    u'%s sends own voice %s to server' %
+                    '%s sends own voice %s to server' %
                     (self.name, voiceId))
         maxGameId = Query('select max(id) from game').records[0][0]
         maxGameId = int(maxGameId) if maxGameId else 0
@@ -450,7 +451,7 @@ class HumanClient(Client):
                 self.__showTables).addErrback(self.tableError)
             if Debug.table:
                 logDebug(
-                    u'%s: --table lets us open an new table %d' %
+                    '%s: --table lets us open an new table %d' %
                     (self.name, SingleshotOptions.table))
             SingleshotOptions.table = False
         elif SingleshotOptions.join:
@@ -459,7 +460,7 @@ class HumanClient(Client):
                 self.__showTables).addErrback(self.tableError)
             if Debug.table:
                 logDebug(
-                    u'%s: --join lets us join table %s' %
+                    '%s: --join lets us join table %s' %
                     (self.name, self._tableById(SingleshotOptions.join)))
             SingleshotOptions.join = False
         elif not self.game and (Internal.autoPlay or (not self.tables and self.hasLocalServer())):
@@ -515,7 +516,7 @@ class HumanClient(Client):
         self.__updateTableList()
         if message:
             if self.name not in args or not message.endswith('has logged out'):
-                logWarning(m18n(message, *args))
+                logWarning(i18n(message, *args))
 
     def __receiveTables(self, tables):
         """now we already know all rulesets for those tables"""
@@ -578,7 +579,7 @@ class HumanClient(Client):
                                 return game.close()
                         if self.beginQuestion:
                             self.beginQuestion.cancel()
-                        Sorry(m18n('Player %1 has left the table', name)).addCallback(
+                        Sorry(i18n('Player %1 has left the table', name)).addCallback(
                             sorried).addCallback(self.showTableList)
                         break
         self.__updateTableList()
@@ -587,7 +588,7 @@ class HumanClient(Client):
         """others chat to me"""
         chatLine = ChatMessage(data)
         if Debug.chat:
-            logDebug(u'got chatLine: %s' % chatLine)
+            logDebug('got chatLine: %s' % chatLine)
         table = self._tableById(chatLine.tableid)
         if not chatLine.isStatusMessage and not table.chatWindow:
             ChatWindow(table)
@@ -622,7 +623,7 @@ class HumanClient(Client):
         def cancelled(dummy):
             """the user does not want to start now. Back to table list"""
             if Debug.table:
-                logDebug(u'%s: Readyforgamestart returns Message.NoGameStart for table %s' % (
+                logDebug('%s: Readyforgamestart returns Message.NoGameStart for table %s' % (
                     self.name, self._tableById(tableid)))
             self.table = None
             self.beginQuestion = None
@@ -630,7 +631,7 @@ class HumanClient(Client):
                 self.__updateTableList()
                 self.tableList.show()
             return Message.NoGameStart
-        if sum(not x[1].startswith(u'Robot ') for x in playerNames) == 1:
+        if sum(not x[1].startswith('Robot ') for x in playerNames) == 1:
             # we play against 3 robots and we already told the server to start:
             # no need to ask again
             return clientReady()
@@ -641,7 +642,7 @@ class HumanClient(Client):
             raise pb.Error(
                 'client.readyForGameStart: tableid %d unknown' %
                 tableid)
-        msg = m18n(
+        msg = i18n(
             "The game on table <numid>%1</numid> can begin. Are you ready to play now?",
             tableid)
         self.beginQuestion = QuestionYesNo(msg, modal=False, caption=self.name).addCallback(
@@ -661,7 +662,7 @@ class HumanClient(Client):
             # update the balances in the status bar:
             Internal.mainWindow.updateGUI()
         assert not self.game.isFirstHand()
-        return Information(m18n("Ready for next hand?"), modal=usingKDE).addCallback(answered)
+        return Information(i18n("Ready for next hand?"), modal=False).addCallback(answered)
 
     def ask(self, move, answers):
         """server sends move. We ask the user. answers is a list with possible answers,
@@ -754,15 +755,13 @@ class HumanClient(Client):
             '%s %s %s %s' %
             (self.game.myself.name if self.game else 'NOGAME', answer, move, answers))
 
-    def remote_abort(self, tableid, message, *args):
+    def remote_abort(self, tableid, message: str, *args):
         """the server aborted this game"""
-        message = nativeString(message)
-        args = nativeStringArgs(args)
         if self.table and self.table.tableid == tableid:
             # translate Robot to Roboter:
             if self.game:
                 args = self.game.players.translatePlayerNames(args)
-            logWarning(m18n(message, *args))
+            logWarning(i18n(message, *args))
             if self.game:
                 self.game.close()
 
@@ -777,14 +776,14 @@ class HumanClient(Client):
         if Internal.scene:
             # update the balances in the status bar:
             Internal.scene.mainWindow.updateGUI()
-        Information(m18n(message, *args)).addCallback(yes)
+        Information(i18n(message, *args)).addCallback(yes)
 
     def remote_serverDisconnects(self, result=None):
         """we logged out or or lost connection to the server.
         Remove visual traces depending on that connection."""
         if Debug.connections and result:
             logDebug(
-                u'server %s disconnects: %s' %
+                'server %s disconnects: %s' %
                 (self.connection.url, result))
         self.connection = None
         game = self.game
@@ -804,7 +803,7 @@ class HumanClient(Client):
         """perspective calls us back"""
         if self.connection and (Debug.traffic or Debug.connections):
             logDebug(
-                u'perspective notifies disconnect: %s' %
+                'perspective notifies disconnect: %s' %
                 self.connection.url)
         self.remote_serverDisconnects()
 
@@ -874,11 +873,15 @@ class HumanClient(Client):
         """clean visual traces and logout from server"""
         def loggedout(result, connection):
             """end the connection from client side"""
+            if Debug.connections:
+                logDebug('server confirmed logout for {}'.format(self))
             connection.connector.disconnect()
             return result
         if self.connection:
             conn = self.connection
             self.connection = None
+            if Debug.connections:
+                logDebug('sending logout to server for {}'.format(self))
             return self.callServer('logout').addCallback(loggedout, conn)
         else:
             return succeed(None)
@@ -897,7 +900,7 @@ class HumanClient(Client):
         if self.game:
             self.game.debug('callServer(%s)' % repr(debugArgs))
         else:
-            logDebug(u'callServer(%s)' % repr(debugArgs))
+            logDebug('callServer(%s)' % repr(debugArgs))
 
     def callServer(self, *args):
         """if we are online, call server"""
@@ -916,7 +919,7 @@ class HumanClient(Client):
                 return self.connection.perspective.callRemote(*args).addErrback(callServerError)
             except pb.DeadReferenceError:
                 logWarning(
-                    m18n(
+                    i18n(
                         'The connection to the server %1 broke, please try again later.',
                         self.connection.url))
                 self.remote_serverDisconnects()
