@@ -1,5 +1,5 @@
 """
-Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 partially based on C++ code from:
 Copyright (C) 2006 Mauricio Piacentini <mauricio@tabuleiro.com>
@@ -19,8 +19,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
-from qt import QWidget, QHBoxLayout
-from kde import KLineEdit
+from qt import QWidget, QHBoxLayout, QLineEdit
 from tileset import Tileset
 from uitile import UITile
 from board import Board, FittingView
@@ -28,7 +27,7 @@ from scene import SceneWithFocusRect
 from common import Internal
 from wind import Wind
 from guiutil import loadUi
-from animation import MoveImmediate
+from animation import AnimationSpeed
 
 
 class TilesetSelector(QWidget):
@@ -39,7 +38,7 @@ class TilesetSelector(QWidget):
         super(TilesetSelector, self).__init__(parent)
 
         loadUi(self)
-        self.kcfg_tilesetName = KLineEdit(self)
+        self.kcfg_tilesetName = QLineEdit(self)
         self.kcfg_tilesetName.setVisible(False)
         self.kcfg_tilesetName.setObjectName('kcfg_tilesetName')
 
@@ -70,7 +69,10 @@ class TilesetSelector(QWidget):
 
         self.tilesetNameList.currentRowChanged.connect(self.tilesetRowChanged)
         self.kcfg_tilesetName.textChanged.connect(self.tilesetNameChanged)
-        self.tilesetList = Tileset.tilesAvailable()
+
+        Tileset.loadAll()
+        # list default tileset first
+        self.tilesetList = Tileset.available()
         for aset in self.tilesetList:
             self.tilesetNameList.addItem(aset.name)
         self.kcfg_tilesetName.setText(Internal.Preferences.tilesetName)
@@ -81,6 +83,7 @@ class TilesetSelector(QWidget):
         for idx, aset in enumerate(self.tilesetList):
             if aset.desktopFileName == name:
                 igrindex = idx
+                break
         self.tilesetNameList.setCurrentRow(igrindex)
 
     def tilesetRowChanged(self):
@@ -91,5 +94,5 @@ class TilesetSelector(QWidget):
         self.tilesetAuthor.setText(selTileset.author)
         self.tilesetContact.setText(selTileset.authorEmail)
         self.tilesetDescription.setText(selTileset.description)
-        with MoveImmediate():
+        with AnimationSpeed():
             self.board.tileset = selTileset
